@@ -1,7 +1,7 @@
 /*
- Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008-2009 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -9,12 +9,12 @@
 #ifndef TC_HEADER_Boot_Platform
 #define TC_HEADER_Boot_Platform
 
-#pragma warning ( disable : 4769 )
+#pragma warning (disable: 4018 4102 4704 4769)
 
 #include "TCdefs.h"
 #include <memory.h>
 
-typedef int bool;
+typedef char bool;
 #define false 0
 #define true 1
 
