@@ -1,7 +1,7 @@
 /*
- Copyright (c) 2005 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2005-2009 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -17,14 +17,7 @@ extern "C" {
 
 #define DATA_POOL_CAPACITY 1000000
 
-typedef struct
-{
-	char	*Key;
-	int		IntKey;
-	void	*Value;
-} DictionaryEntry;
-
-int AddDictionaryEntry (char *key, int intKey, void *value);
+void AddDictionaryEntry (char *key, int intKey, void *value);
 void *GetDictionaryValue (const char *key);
 void *GetDictionaryValueByInt (int intKey);
 void *AddPoolData (void *data, size_t dataSize);
