@@ -4,8 +4,8 @@
  Copyright (c) 1998-2000 Paul Le Roux and which is governed by the 'License
  Agreement for Encryption for the Masses'. Modifications and additions to
  the original source code (contained in this file) and all other portions of
- this file are Copyright (c) 2003-2008 TrueCrypt Foundation and are governed
- by the TrueCrypt License 2.7 the full text of which is contained in the
+ this file are Copyright (c) 2003-2009 TrueCrypt Foundation and are governed
+ by the TrueCrypt License 2.8 the full text of which is contained in the
  file License.txt included in TrueCrypt binary and source code distribution
  packages. */
 
@@ -20,15 +20,15 @@ typedef struct fatparams_t
 	int media;
 	int cluster_size;
 	int fat_length;
-	int dir_entries;
-	int sector_size;
+	uint16 dir_entries;
+	uint16 sector_size;
 	int hidden;
 	__int16 reserved;
-	int sectors;
+	uint16 sectors;
 	unsigned int total_sect;
 
-	int heads;
-	int secs_track;
+	uint16 heads;
+	uint16 secs_track;
 
 } fatparams;
 
