@@ -5,7 +5,7 @@
  Agreement for Encryption for the Masses'. Modifications and additions to
  the original source code (contained in this file) and all other portions of
  this file are Copyright (c) 2003-2009 TrueCrypt Foundation and are governed
- by the TrueCrypt License 2.7 the full text of which is contained in the
+ by the TrueCrypt License 2.8 the full text of which is contained in the
  file License.txt included in TrueCrypt binary and source code distribution
  packages. */
 
@@ -22,6 +22,7 @@ static BOOL bDidSlowPoll = FALSE;
 BOOL volatile bFastPollEnabled = TRUE;	/* Used to reduce CPU load when performing benchmarks */
 BOOL volatile bRandmixEnabled = TRUE;	/* Used to reduce CPU load when performing benchmarks */
 static BOOL RandomPoolEnrichedByUser = FALSE;
+static HANDLE PeriodicFastPollThreadHandle = NULL;
 
 /* Macro to add a single byte to the pool */
 #define RandaddByte(x) {\
@@ -100,7 +101,7 @@ Randinit ()
 	else
 		CryptoAPIAvailable = TRUE;
 
-	if (_beginthread (ThreadSafeThreadFunction, 0, NULL) == -1)
+	if (!(PeriodicFastPollThreadHandle = (HANDLE) _beginthreadex (NULL, 0, PeriodicFastPollThreadProc, NULL, 0, NULL)))
 		goto error;
 
 	return 0;
@@ -131,17 +132,8 @@ void RandStop (BOOL freePool)
 
 	LeaveCriticalSection (&critRandProt);
 
-	for (;;)
-	{
-		Sleep (250);
-		EnterCriticalSection (&critRandProt);
-		if (bThreadTerminate == FALSE)
-		{
-			LeaveCriticalSection (&critRandProt);
-			break;
-		}
-		LeaveCriticalSection (&critRandProt);
-	}
+	if (PeriodicFastPollThreadHandle)
+		WaitForSingleObject (PeriodicFastPollThreadHandle, INFINITE);
 
 	if (hNetAPI32 != 0)
 	{
@@ -499,8 +491,7 @@ KeyboardProc (int nCode, WPARAM wParam, LPARAM lParam)
 }
 
 /* This is the thread function which will poll the system for randomness */
-void
-ThreadSafeThreadFunction (void *dummy)
+static unsigned __stdcall PeriodicFastPollThreadProc (void *dummy)
 {
 	if (dummy);		/* Remove unused parameter warning */
 
@@ -512,7 +503,7 @@ ThreadSafeThreadFunction (void *dummy)
 		{
 			bThreadTerminate = FALSE;
 			LeaveCriticalSection (&critRandProt);
-			_endthread ();
+			_endthreadex (0);
 		}
 		else if (bFastPollEnabled)
 		{
