@@ -5,7 +5,7 @@
  Agreement for Encryption for the Masses'. Modifications and additions to
  the original source code (contained in this file) and all other portions of
  this file are Copyright (c) 2003-2009 TrueCrypt Foundation and are governed
- by the TrueCrypt License 2.7 the full text of which is contained in the
+ by the TrueCrypt License 2.8 the full text of which is contained in the
  file License.txt included in TrueCrypt binary and source code distribution
  packages. */
 
@@ -13,7 +13,6 @@
 
 #ifndef TC_WINDOWS_BOOT
 #include <fcntl.h>
-#include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
@@ -21,8 +20,12 @@
 #endif
 
 #include <stddef.h>
+#include <string.h>
 #include <io.h>
+
+#ifndef DEVICE_DRIVER
 #include "Random.h"
+#endif
 
 #include "Crc.h"
 #include "Crypto.h"
@@ -151,8 +154,8 @@ int ReadVolumeHeader (BOOL bBoot, char *encryptedHeader, Password *password, PCR
 	KeyDerivationWorkItem *keyDerivationWorkItems;
 	KeyDerivationWorkItem *item;
 	int pkcs5PrfCount = LAST_PRF_ID - FIRST_PRF_ID + 1;
-	int encryptionThreadCount = GetEncryptionThreadCount();
-	int queuedWorkItems = 0;
+	size_t encryptionThreadCount = GetEncryptionThreadCount();
+	size_t queuedWorkItems = 0;
 	LONG outstandingWorkItemCount = 0;
 	int i;
 
