@@ -1,7 +1,7 @@
 /*
- Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008-2009 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -139,7 +139,7 @@ wipe3:
 }
 
 
-size_t GetWipePassCount (WipeAlgorithmId algorithm)
+int GetWipePassCount (WipeAlgorithmId algorithm)
 {
 	switch (algorithm)
 	{
