@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2008-2009 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -180,7 +180,7 @@ namespace TrueCrypt
 
 		Pool.Zero();
 		Buffer buffer (1);
-		for (int i = 0; i < PoolSize * 10; ++i)
+		for (size_t i = 0; i < PoolSize * 10; ++i)
 		{
 			buffer[0] = (byte) i;
 			AddToPool (buffer);
