@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2008-2009 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -21,9 +21,6 @@
 #define TC_ENC_IO_QUEUE_PREALLOCATED_ITEM_COUNT 8
 #define TC_ENC_IO_QUEUE_PREALLOCATED_IO_REQUEST_COUNT 16
 
-#define TC_ENC_IO_QUEUE_MEM_ALLOC_RETRY_DELAY 1
-#define TC_ENC_IO_QUEUE_MEM_ALLOC_TIMEOUT 1000
-
 
 typedef struct EncryptedIoQueueBufferStruct
 {
@@ -97,7 +94,6 @@ typedef struct
 	KEVENT NoOutstandingIoEvent;
 	LONG IoThreadPendingRequestCount;
 
-	KEVENT RequestCompletedEvent;
 	KEVENT PoolBufferFreeEvent;
 
 	__int64 TotalBytesRead;
@@ -126,7 +122,6 @@ typedef struct
 	BOOL Write;
 	ULONG OriginalLength;
 	LARGE_INTEGER OriginalOffset;
-	LONG OutstandingRequestCount;
 	NTSTATUS Status;
 
 #ifdef TC_TRACE_IO_QUEUE
