@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2007-2008 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -76,6 +76,16 @@ public:
 		return BaseCom::CallDriver (ioctl, input, output);
 	}
 
+	virtual DWORD STDMETHODCALLTYPE CopyFile (BSTR sourceFile, BSTR destinationFile)
+	{
+		return BaseCom::CopyFile (sourceFile, destinationFile);
+	}
+
+	virtual DWORD STDMETHODCALLTYPE DeleteFile (BSTR file)
+	{
+		return BaseCom::DeleteFile (file);
+	}
+
 	virtual BOOL STDMETHODCALLTYPE FormatNtfs (int driveNo, int clusterSize)
 	{
 		return ::FormatNtfs (driveNo, clusterSize);
@@ -98,6 +108,11 @@ public:
 		return BaseCom::RegisterFilterDriver (registerDriver, volumeClass);
 	}
 
+	virtual DWORD STDMETHODCALLTYPE RegisterSystemFavoritesService (BOOL registerService)
+	{
+		return BaseCom::RegisterSystemFavoritesService (registerService);
+	}
+
 	virtual DWORD STDMETHODCALLTYPE SetDriverServiceStartType (DWORD startType)
 	{
 		return BaseCom::SetDriverServiceStartType (startType);
