@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -39,7 +39,7 @@ namespace TrueCrypt
 		wxStandardPaths stdPaths;
 		DirectoryPath configDir;
 		
-		if (!Core->IsInTravelMode())
+		if (!Core->IsInPortableMode())
 		{
 #ifdef TC_MACOSX
 			wxFileName configPath (L"~/Library/Application Support/TrueCrypt");
