@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2007-2009 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -92,7 +92,17 @@ public:
 		MainDlg = (HWND) hWnd;
 		return ::ChangePwd (CW2A (volumePath), oldPassword, newPassword, pkcs5, (HWND) hWnd);
 	}
-	
+
+	virtual DWORD STDMETHODCALLTYPE CopyFile (BSTR sourceFile, BSTR destinationFile)
+	{
+		return BaseCom::CopyFile (sourceFile, destinationFile);
+	}
+
+	virtual DWORD STDMETHODCALLTYPE DeleteFile (BSTR file)
+	{
+		return BaseCom::DeleteFile (file);
+	}
+
 	virtual BOOL STDMETHODCALLTYPE IsPagingFileActive (BOOL checkNonWindowsPartitionsOnly)
 	{
 		return BaseCom::IsPagingFileActive (checkNonWindowsPartitionsOnly);
@@ -108,6 +118,11 @@ public:
 		return BaseCom::RegisterFilterDriver (registerDriver, volumeClass);
 	}
 
+	virtual DWORD STDMETHODCALLTYPE RegisterSystemFavoritesService (BOOL registerService)
+	{
+		return BaseCom::RegisterSystemFavoritesService (registerService);
+	}
+
 	virtual DWORD STDMETHODCALLTYPE SetDriverServiceStartType (DWORD startType)
 	{
 		return BaseCom::SetDriverServiceStartType (startType);
