@@ -5,7 +5,7 @@
  Agreement for Encryption for the Masses'. Modifications and additions to
  the original source code (contained in this file) and all other portions of
  this file are Copyright (c) 2003-2009 TrueCrypt Foundation and are governed
- by the TrueCrypt License 2.7 the full text of which is contained in the
+ by the TrueCrypt License 2.8 the full text of which is contained in the
  file License.txt included in TrueCrypt binary and source code distribution
  packages. */
 
@@ -21,6 +21,8 @@ enum mount_list_item_types
 	TC_MLIST_ITEM_SYS_DRIVE
 };
 
+#define TC_MAIN_WINDOW_FLAG_ADMIN_PRIVILEGES	0x1
+
 #define TRAYICON_MENU_DRIVE_OFFSET	9000
 
 #define WM_COPY_SET_VOLUME_NAME		"VNAM"
@@ -42,18 +44,12 @@ typedef struct
 } VOLUME_NOTIFICATIONS_LIST;
 
 
-typedef struct
-{
-	BOOL CacheBootPassword;
-} DriverConfiguration;
-
-
 extern VOLUME_NOTIFICATIONS_LIST VolumeNotificationsList;
 
 extern BOOL bPlaySoundOnHotkeyMountDismount;
 extern BOOL bDisplayMsgBoxOnHotkeyDismount;
 
-void localcleanup ( void );
+static void localcleanup ( void );
 void EndMainDlg ( HWND hwndDlg );
 void EnableDisableButtons ( HWND hwndDlg );
 BOOL VolumeSelected (HWND hwndDlg );
@@ -70,14 +66,13 @@ LPARAM GetItemLong ( HWND hTree, int itemNo );
 BOOL CALLBACK CommandHelpDlgProc ( HWND hwndDlg , UINT msg , WPARAM wParam , LPARAM lParam );
 BOOL CALLBACK MainDialogProc ( HWND hwndDlg , UINT uMsg , WPARAM wParam , LPARAM lParam );
 void ExtractCommandLine ( HWND hwndDlg , char *lpszCommandLine );
-int WINAPI WINMAIN ( HINSTANCE hInstance , HINSTANCE hPrevInstance , char *lpszCommandLine , int nCmdShow );
-void WipeCache (HWND hwndDlg, BOOL silent);
+static void WipeCache (HWND hwndDlg, BOOL silent);
 void OpenVolumeExplorerWindow (int driveNo);
 BOOL TaskBarIconAdd (HWND hwnd);
 BOOL TaskBarIconRemove (HWND hwnd);
 void DismountIdleVolumes ();
-BOOL MountFavoriteVolumes ();
-void SaveFavoriteVolumes ();
+BOOL MountFavoriteVolumes (BOOL systemFavorites);
+void SaveFavoriteVolumes (BOOL systemFavorites);
 static void SaveDefaultKeyFilesParam (void);
 static BOOL Dismount (HWND hwndDlg, int nDosDriveNo);
 static BOOL DismountAll (HWND hwndDlg, BOOL forceUnmount, BOOL interact, int dismountMaxRetries, int dismountAutoRetryDelay);
@@ -96,12 +91,12 @@ int BackupVolumeHeader (HWND hwndDlg, BOOL bRequireConfirmation, char *lpszVolum
 int RestoreVolumeHeader (HWND hwndDlg, char *lpszVolume);
 void SecurityTokenPreferencesDialog (HWND hwndDlg);
 static BOOL CALLBACK BootLoaderPreferencesDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lParam);
+static BOOL CALLBACK SystemFavoritesSettingsDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lParam);
 void MountSelectedVolume (HWND hwndDlg, BOOL mountWithOptions);
+uint32 ReadDriverConfigurationFlags ();
+void SetDriverConfigurationFlag (uint32 flag, BOOL state);
 
 #ifdef __cplusplus
 }
 
-void ReadDriverConfiguration (DriverConfiguration *configuration);
-void WriteDriverConfiguration (DriverConfiguration *configuration);
-
 #endif
