@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
+ Governed by the TrueCrypt License 2.8 the full text of which is contained
  in the file License.txt included in TrueCrypt binary and source code
  distribution packages.
 */
@@ -45,7 +45,7 @@ namespace TrueCrypt
 			uint64 listSize;
 			sr.Deserialize ("ListSize", listSize);
 
-			for (int i = 0; i < listSize; i++)
+			for (size_t i = 0; i < listSize; i++)
 			{
 				shared_ptr <T> p (dynamic_cast <T *> (DeserializeNew (stream)));
 				if (!p)
