@@ -1,9 +1,9 @@
 /*
- Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.7 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 2.8 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
 #include "Cipher.h"
@@ -413,7 +413,7 @@ namespace TrueCrypt
 	{
 		unsigned __int8 p[ENCRYPTION_DATA_UNIT_SIZE];
 		uint64 dataUnitNo;
-		int i;
+		size_t i;
 
 		for (i = 0; i < array_capacity (XtsTestVectors); i++)
 		{
